@@ -1,6 +1,5 @@
 import logging
 
-from dvc.repo.experiments.utils import fix_exp_head
 from dvc.utils.diff import diff as _diff
 from dvc.utils.diff import format_dict
 
@@ -15,16 +14,12 @@ def diff(repo, *args, a_rev=None, b_rev=None, param_deps=False, **kwargs):
         return {}
 
     if a_rev:
-        a_rev = fix_exp_head(repo.scm, a_rev)
         rev = resolve_rev(repo.scm, a_rev)
         old = _collect_experiment_commit(repo, rev, param_deps=param_deps)
     else:
-        old = _collect_experiment_commit(
-            repo, fix_exp_head(repo.scm, "HEAD"), param_deps=param_deps
-        )
+        old = _collect_experiment_commit(repo, "HEAD", param_deps=param_deps)
 
     if b_rev:
-        b_rev = fix_exp_head(repo.scm, b_rev)
         rev = resolve_rev(repo.scm, b_rev)
         new = _collect_experiment_commit(repo, rev, param_deps=param_deps)
     else:
