@@ -8,27 +8,23 @@ from typing import (
     Callable,
     Dict,
     Iterable,
+    List,
     Optional,
     TextIO,
     Tuple,
     Union,
-    cast,
 )
 
-from funcy import compact, lremove
-from rich.rule import Rule
-from rich.syntax import Syntax
+from funcy import compact, lremove, lsplit
 
 from dvc.exceptions import DvcException
 from dvc.stage import PipelineStage
-from dvc.stage.serialize import to_pipeline_file
 from dvc.types import OptStr
-from dvc.utils.serialize import dumps_yaml
 
 if TYPE_CHECKING:
     from dvc.repo import Repo
     from dvc.dvcfile import DVCFile
-    from rich.tree import Tree
+    from dvc.dependency import Dependency
 
 from dvc.ui import ui
 
@@ -79,79 +75,41 @@ def _disable_logging(highest_level=logging.CRITICAL):
         logging.disable(previous_level)
 
 
-def build_workspace_tree(workspace: Dict[str, str]) -> "Tree":
-    from rich.tree import Tree
-
-    tree = Tree(
-        "DVC assumes the following workspace structure:",
-        highlight=True,
-    )
-    for value in sorted(workspace.values()):
-        tree.add(f"[green]{value}[/green]")
-    return tree
-
-
-PIPELINE_FILE_LINK = "https://s.dvc.org/g/pipeline-files"
-
-
 def init_interactive(
-    name: str,
     defaults: Dict[str, str],
     provided: Dict[str, str],
     validator: Callable[[str, str], Union[str, Tuple[str, str]]] = None,
     live: bool = False,
     stream: Optional[TextIO] = None,
 ) -> Dict[str, str]:
-    command = provided.pop("cmd", None)
-    primary = lremove(provided.keys(), ["code", "data", "models", "params"])
-    secondary = lremove(
-        provided.keys(), ["live"] if live else ["metrics", "plots"]
+    command_prompts = lremove(provided.keys(), ["cmd"])
+    dependencies_prompts = lremove(provided.keys(), ["code", "data", "params"])
+    outputs_prompts = lremove(
+        provided.keys(),
+        ["models"] + (["live"] if live else ["metrics", "plots"]),
     )
-    prompts = primary + secondary
-
-    workspace = {**defaults, **provided}
-    if not live and "live" not in provided:
-        workspace.pop("live", None)
-    for key in ("plots", "metrics"):
-        if live and key not in provided:
-            workspace.pop(key, None)
 
     ret: Dict[str, str] = {}
-    if command:
-        ret["cmd"] = command
+    if "cmd" in provided:
+        ret["cmd"] = provided["cmd"]
 
-    if not prompts and command:
-        return ret
-
-    ui.error_write(
-        f"This command will guide you to set up a [bright_blue]{name}[/]",
-        "stage in [green]dvc.yaml[/].",
-        f"\nSee [repr.url]{PIPELINE_FILE_LINK}[/].\n",
-        styled=True,
-    )
-
-    if not command:
-        ret.update(
-            compact(_prompts(["cmd"], allow_omission=False, stream=stream))
+    for heading, prompts, allow_omission in (
+        ("", command_prompts, False),
+        ("Enter experiment dependencies.", dependencies_prompts, True),
+        ("Enter experiment outputs.", outputs_prompts, True),
+    ):
+        if prompts and heading:
+            ui.error_write(heading, styled=True)
+        response = _prompts(
+            prompts,
+            defaults=defaults,
+            allow_omission=allow_omission,
+            validator=validator,
+            stream=stream,
         )
+        ret.update(compact(response))
         if prompts:
             ui.error_write(styled=True)
-
-    if not prompts:
-        return ret
-
-    ui.error_write(
-        "Enter the paths for dependencies and outputs of the command.",
-        styled=True,
-    )
-    if workspace:
-        ui.error_write(build_workspace_tree(workspace), styled=True)
-    ui.error_write(styled=True)
-    ret.update(
-        compact(
-            _prompts(prompts, defaults, validator=validator, stream=stream)
-        )
-    )
     return ret
 
 
@@ -172,33 +130,59 @@ def validate_prompts(
 ) -> Union[Any, Tuple[Any, str]]:
     from dvc.ui.prompt import InvalidResponse
 
+    msg_format = "[yellow]'{0}' does not exist, the {1} will be created.[/]"
     if key == "params":
-        import errno
-
-        from dvc.dependency.param import ParamsDependency
+        from dvc.dependency.param import (
+            MissingParamsFile,
+            ParamsDependency,
+            ParamsIsADirectoryError,
+        )
 
         assert isinstance(value, str)
-        msg_format = (
-            "[prompt.invalid]'{0}' {1}. "
-            "Please retry with an existing parameters file."
-        )
         try:
             ParamsDependency(None, value, repo=repo).validate_filepath()
-        except (IsADirectoryError, FileNotFoundError) as e:
-            suffices = {
-                errno.EISDIR: "is a directory",
-                errno.ENOENT: "does not exist",
-            }
-            raise InvalidResponse(msg_format.format(value, suffices[e.errno]))
+        except MissingParamsFile:
+            return value, msg_format.format(value, "file")
+        except ParamsIsADirectoryError:
+            raise InvalidResponse(
+                f"[prompt.invalid]'{value}' is a directory. "
+                "Please retry with an existing parameters file."
+            )
     elif key in ("code", "data"):
         if not os.path.exists(value):
-            return value, (
-                f"[yellow]'{value}' does not exist in the workspace. "
-                '"exp run" may fail.[/]'
-            )
+            typ = "file" if is_file(value) else "directory"
+            return value, msg_format.format(value, typ)
     return value
 
 
+def is_file(path: str) -> bool:
+    _, ext = os.path.splitext(path)
+    return bool(ext)
+
+
+def init_deps(stage: PipelineStage) -> List["Dependency"]:
+    from funcy import rpartial
+
+    from dvc.dependency import ParamsDependency
+    from dvc.fs.local import localfs
+
+    new_deps = [dep for dep in stage.deps if not dep.exists]
+    params, deps = lsplit(rpartial(isinstance, ParamsDependency), new_deps)
+
+    # always create a file for params, detect file/folder based on extension
+    # for other dependencies
+    dirs = [dep.fs_path for dep in deps if not is_file(dep.fs_path)]
+    files = [dep.fs_path for dep in deps + params if is_file(dep.fs_path)]
+    for path in dirs:
+        localfs.makedirs(path)
+    for path in files:
+        localfs.makedirs(localfs.path.parent(path), exist_ok=True)
+        with localfs.open(path, "w", encoding="utf-8"):
+            pass
+
+    return new_deps
+
+
 def init(
     repo: "Repo",
     name: str = "train",
@@ -208,7 +192,7 @@ def init(
     interactive: bool = False,
     force: bool = False,
     stream: Optional[TextIO] = None,
-) -> PipelineStage:
+) -> Tuple[PipelineStage, List["Dependency"]]:
     from dvc.dvcfile import make_dvcfile
 
     dvcfile = make_dvcfile(repo, "dvc.yaml")
@@ -221,7 +205,6 @@ def init(
 
     if interactive:
         defaults = init_interactive(
-            name,
             validator=partial(validate_prompts, repo),
             defaults=defaults,
             live=with_live,
@@ -241,7 +224,6 @@ def init(
     context: Dict[str, str] = {**defaults, **overrides}
     assert "cmd" in context
 
-    params_kv = []
     params = context.get("params")
     if params:
         from dvc.dependency.param import (
@@ -251,10 +233,11 @@ def init(
         )
 
         try:
-            params_d = ParamsDependency(None, params, repo=repo).read_file()
-        except (MissingParamsFile, ParamsIsADirectoryError) as exc:
+            ParamsDependency(None, params, repo=repo).validate_filepath()
+        except ParamsIsADirectoryError as exc:
             raise DvcException(f"{exc}.")  # swallow cause for display
-        params_kv.append({params: list(params_d.keys())})
+        except MissingParamsFile:
+            pass
 
     checkpoint_out = bool(context.get("live"))
     models = context.get("models")
@@ -262,7 +245,7 @@ def init(
         name=name,
         cmd=context["cmd"],
         deps=compact([context.get("code"), context.get("data")]),
-        params=params_kv,
+        params=[{params: None}] if params else None,
         metrics_no_cache=compact([context.get("metrics")]),
         plots_no_cache=compact([context.get("plots")]),
         live=context.get("live"),
@@ -270,27 +253,12 @@ def init(
         **{"checkpoints" if checkpoint_out else "outs": compact([models])},
     )
 
-    if interactive:
-        ui.error_write(Rule(style="green"), styled=True)
-        _yaml = dumps_yaml(to_pipeline_file(cast(PipelineStage, stage)))
-        syn = Syntax(_yaml, "yaml", theme="ansi_dark")
-        ui.error_write(syn, styled=True)
-
-    from dvc.ui.prompt import Confirm
-
-    if not interactive or Confirm.ask(
-        "Do you want to add the above contents to dvc.yaml?",
-        console=ui.error_console,
-        default=True,
-        stream=stream,
-    ):
-        with _disable_logging(), repo.scm_context(autostage=True, quiet=True):
-            stage.dump(update_lock=False)
-            stage.ignore_outs()
-            if params:
-                repo.scm_context.track_file(params)
-    else:
-        raise DvcException("Aborting ...")
+    with _disable_logging(), repo.scm_context(autostage=True, quiet=True):
+        stage.dump(update_lock=False)
+        stage.ignore_outs()
+        initialized_deps = init_deps(stage)
+        if params:
+            repo.scm_context.track_file(params)
 
     assert isinstance(stage, PipelineStage)
-    return stage
+    return stage, initialized_deps
